@@ -315,15 +315,15 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
 
             if ('is_inherited' in table_info and
                 table_info['is_inherited'] == '1')\
-                    or ('inherited_tables_cnt' in table_info and
-                        len(table_info['inherited_tables_cnt']) > 0):
+                    or ('relhassubclass' in table_info and
+                        table_info['relhassubclass']):
                 default_val = 'icon-table-multi-inherit'
             else:
                 default_val = 'icon-table-inherits'
         elif ('is_inherited' in table_info and
               table_info['is_inherited'] == '1')\
-                or ('inherited_tables_cnt' in table_info and
-                    len(table_info['inherited_tables_cnt']) > 0):
+                or ('relhassubclass' in table_info and
+                    table_info['relhassubclass']):
             default_val = 'icon-table-inherited'
 
         return super(TableView, self).\
@@ -905,10 +905,18 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
 
                     for c in final_columns:
                         if 'attacl' in c:
-                            c['attacl'] = parse_priv_to_db(
-                                c['attacl'], self.column_acl
-                            )
-
+                            if 'added' in c['attacl']:
+                                c['attacl']['added'] = parse_priv_to_db(
+                                    c['attacl']['added'], self.column_acl
+                                )
+                            elif 'changed' in c['attacl']:
+                                c['attacl']['changed'] = parse_priv_to_db(
+                                    c['attacl']['changed'], self.column_acl
+                                )
+                            elif 'deleted' in c['attacl']:
+                                c['attacl']['deleted'] = parse_priv_to_db(
+                                    c['attacl']['deleted'], self.column_acl
+                                )
                         if 'cltype' in c:
                             # check type for '[]' in it
                             c['cltype'], c['hasSqrBracket'] = \
