@@ -78,7 +78,7 @@ class TriggerModule(CollectionNodeModule):
             if 'vid' not in kwargs:
                 return True
 
-            template_path = 'trigger/sql/#{0}#'.format(manager.version)
+            template_path = 'triggers/sql/#{0}#'.format(manager.version)
             SQL = render_template("/".join(
                 [template_path, 'backend_support.sql']), vid=kwargs['vid']
             )
@@ -132,7 +132,7 @@ class TriggerModule(CollectionNodeModule):
         """
         snippets = [
             render_template(
-                "trigger/css/trigger.css",
+                "triggers/css/trigger.css",
                 node_type=self.node_type
             )
         ]
@@ -155,10 +155,6 @@ class TriggerView(PGChildNodeView):
     * __init__(**kwargs)
       - Method is used to initialize the TriggerView and it's base view.
 
-    * module_js()
-      - This property defines (if javascript) exists for this node.
-        Override this property for your own logic
-
     * check_precondition()
       - This function will behave as a decorator which will checks
         database connection before running view, it will also attaches
@@ -248,7 +244,6 @@ class TriggerView(PGChildNodeView):
         'stats': [{'get': 'statistics'}],
         'dependency': [{'get': 'dependencies'}],
         'dependent': [{'get': 'dependents'}],
-        'module.js': [{}, {}, {'get': 'module_js'}],
         'get_triggerfunctions': [{'get': 'get_trigger_functions'},
                                  {'get': 'get_trigger_functions'}],
         'enable': [{'put': 'enable_disable_trigger'}]
@@ -277,7 +272,7 @@ class TriggerView(PGChildNodeView):
                 kwargs['did'] in self.manager.db_info else 0
 
             # we will set template path for sql scripts
-            self.template_path = 'trigger/sql/#{0}#'.format(
+            self.template_path = 'triggers/sql/#{0}#'.format(
                 self.manager.version)
             # Store server type
             self.server_type = self.manager.server_type
