@@ -24,6 +24,7 @@ define('pgadmin.node.pga_jobstep', [
           'jstonerror',
         ],
         hasStatistics: false,
+        canDropCascade: false,
       });
   }
 
@@ -122,10 +123,13 @@ define('pgadmin.node.pga_jobstep', [
             var args = arguments && arguments.length > 1 && arguments[1];
 
             if (args) {
-              this.set(
-                'jstdbname',
-                (args['node_info'] || args.collection.top['node_info'])['server']['db']
-              );
+              if (!_.isUndefined(args['node_info']) ||
+                  !_.isUndefined(args.collection.top['node_info'])) {
+                this.set(
+                  'jstdbname',
+                  (args['node_info'] || args.collection.top['node_info'])['server']['db']
+                );
+              }
             }
           }
         },
