@@ -1,5 +1,5 @@
 class QueryToolLocatorsCss:
-    btn_save = "#btn-save"
+    btn_save_file = "#btn-save-file"
     btn_execute_query = "#btn-flash"
     btn_query_dropdown = "#btn-query-dropdown"
     btn_auto_rollback = "#btn-auto-rollback"
@@ -20,3 +20,4 @@ class QueryToolLocatorsCss:
     query_history_selected = "#query_list .selected"
     query_history_detail = "#query_detail"
     editor_panel = "#output-panel"
+    query_messages_panel = ".sql-editor-message"
