@@ -29,7 +29,7 @@ function updateUIPreferences(sqlEditor) {
     .attr('title', shortcut_accesskey_title('Open File',preferences.btn_open_file))
     .attr('accesskey', shortcut_key(preferences.btn_open_file));
 
-  $el.find('#btn-save')
+  $el.find('#btn-save-file')
     .attr('title', shortcut_accesskey_title('Save File',preferences.btn_save_file))
     .attr('accesskey', shortcut_key(preferences.btn_save_file));
 
@@ -97,6 +97,10 @@ function updateUIPreferences(sqlEditor) {
     .attr('title',
       shortcut_title('Download as CSV',preferences.download_csv));
 
+  $el.find('#btn-save-data')
+    .attr('title',
+      shortcut_title('Save Data Changes',preferences.save_data));
+
   $el.find('#btn-commit')
     .attr('title',
       shortcut_title('Commit',preferences.commit_transaction));
@@ -134,6 +138,20 @@ function updateUIPreferences(sqlEditor) {
     $el.find('.explain-timing').addClass('visibility-hidden');
   }
 
+  if (preferences.explain_summary) {
+    $el.find('.explain-summary').removeClass('visibility-hidden');
+  }
+  else {
+    $el.find('.explain-summary').addClass('visibility-hidden');
+  }
+
+  if (preferences.explain_settings) {
+    $el.find('.explain-settings').removeClass('visibility-hidden');
+  }
+  else {
+    $el.find('.explain-settings').addClass('visibility-hidden');
+  }
+
   /* Connection status check */
   /* remove the status checker if present */
   if(sqlEditor.connIntervalId != null) {
