@@ -30,6 +30,7 @@ describe('ExplainStatistics', () => {
 
       statsModel.set('JIT', []);
       statsModel.set('Triggers', []);
+      statsModel.set('Summary', {});
       statsModel.set_statistics(tooltipContainer);
 
       expect($('.pg-explain-stats-area').hasClass('d-none')).toEqual(true);
@@ -93,4 +94,37 @@ describe('ExplainStatistics', () => {
       expect(tooltipContainer.css('opacity')).toEqual('0');
     });
   });
+
+  describe('Summary', () => {
+    beforeEach(function() {
+      $('body').append(statsDiv);
+      statsModel.set('JIT', []);
+      statsModel.set('Triggers', []);
+      statsModel.set('Summary', {
+        'Planning Time': 0.12,
+        'Execution Time': 2.34,
+      });
+      statsModel.set_statistics(tooltipContainer);
+    });
+
+    it('Statistics button should be visible', () => {
+      expect($('.pg-explain-stats-area').hasClass('d-none')).toEqual(false);
+    });
+
+    it('Mouse over event should be trigger', () => {
+      // Trigger mouse over event
+      var hoverEvent = new $.Event('mouseover');
+      $('.pg-explain-stats-area').trigger(hoverEvent);
+
+      expect(tooltipContainer.css('opacity')).toEqual('0.8');
+    });
+
+    it('Mouse out event should be trigger', () => {
+      // Trigger mouse out event
+      var hoverEvent = new $.Event('mouseout');
+      $('.pg-explain-stats-area').trigger(hoverEvent);
+
+      expect(tooltipContainer.css('opacity')).toEqual('0');
+    });
+  });
 });
