@@ -991,6 +991,8 @@ def get_server_type(server):
         pg_cursor.execute("SELECT version()")
         version_string = pg_cursor.fetchone()
         connection.close()
+        if type(version_string) == tuple:
+            version_string = version_string[0]
 
         if "Greenplum Database" in version_string:
             return 'gpdb'
@@ -1013,12 +1015,12 @@ def check_binary_path_or_skip_test(cls, utility_name):
             )
         )
 
-        from pgadmin.utils import is_utility_exists
+        from pgadmin.utils import does_utility_exist
         binary_path = os.path.join(
             cls.server['default_binary_paths'][cls.server['type']],
             utility_name
         )
-        retVal = is_utility_exists(binary_path)
+        retVal = does_utility_exist(binary_path)
         if retVal is not None:
             cls.skipTest(retVal)
 
