@@ -20,12 +20,6 @@ import sys
 import traceback
 import json
 import random
-import flask
-
-from selenium import webdriver
-from selenium.webdriver.chrome.options import Options
-from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
-
 
 import unittest
 
@@ -200,7 +194,15 @@ def get_test_modules(arguments):
     if arguments['exclude'] is not None:
         exclude_pkgs += arguments['exclude'].split(',')
 
-    if 'feature_tests' not in exclude_pkgs:
+    if 'feature_tests' not in exclude_pkgs and \
+            (arguments['pkg'] is None or arguments['pkg'] == "all" or
+             arguments['pkg'] == "feature_tests"):
+
+        from selenium import webdriver
+        from selenium.webdriver.chrome.options import Options
+        from selenium.webdriver.common.desired_capabilities import \
+            DesiredCapabilities
+
         default_browser = 'chrome'
 
         # Check default browser provided through command line. If provided
@@ -233,6 +235,7 @@ def get_test_modules(arguments):
                     if test_setup.config_data['headless_chrome']:
                         options.add_argument("--headless")
             options.add_argument("--window-size=1280,1024")
+            options.add_argument("--disable-infobars")
             options.add_experimental_option('w3c', False)
             driver = webdriver.Chrome(chrome_options=options)
 
@@ -444,6 +447,7 @@ if __name__ == '__main__':
 
             # Add the server version in server information
             server_information['server_version'] = connection.server_version
+            server_information['type'] = server['type']
 
             # Drop the database if already exists.
             test_utils.drop_database(connection, test_db_name)
